summaryrefslogtreecommitdiffstats
path: root/src/usr/hwas/common/deconfigGard.C
diff options
context:
space:
mode:
authorMarty Gloff <mgloff@us.ibm.com>2016-02-01 09:07:03 -0600
committerMatthew A. Ploetz <maploetz@us.ibm.com>2016-04-27 06:40:46 -0400
commit76febbb5c230f1231be719831f84923fb802cb95 (patch)
tree54b45deb80a2a091db0c44daa19751e191e70afc /src/usr/hwas/common/deconfigGard.C
parent5e80adfa475e07dcd896de7ced5004cf51e95ff5 (diff)
downloadtalos-hostboot-76febbb5c230f1231be719831f84923fb802cb95.tar.gz
talos-hostboot-76febbb5c230f1231be719831f84923fb802cb95.zip
P9 changes for PR core restriction
Covers the work required to support the P9 module vpd and new EQ/EX/EC core structure in relation to the processing of the PR keyword to restrict the number of cores. Add new traces or enhance old traces with additional data to improve debug. Update the module vpd binary for our standalone model. Change-Id: I20018ccf1daa429e5b0ad9e38f50b1bc5943bcb5 RTC:145459 Reviewed-on: http://ralgit01.raleigh.ibm.com/gerrit1/705 Tested-by: Jenkins Server Tested-by: FSP CI Jenkins Reviewed-by: Christian R. Geddes <crgeddes@us.ibm.com> Reviewed-by: Daniel M. Crowell <dcrowell@us.ibm.com> Reviewed-by: Matthew A. Ploetz <maploetz@us.ibm.com>
Diffstat (limited to 'src/usr/hwas/common/deconfigGard.C')
-rw-r--r--src/usr/hwas/common/deconfigGard.C12
1 files changed, 6 insertions, 6 deletions
diff --git a/src/usr/hwas/common/deconfigGard.C b/src/usr/hwas/common/deconfigGard.C
index 5e08ed095..8071d7df5 100644
--- a/src/usr/hwas/common/deconfigGard.C
+++ b/src/usr/hwas/common/deconfigGard.C
@@ -752,7 +752,7 @@ errlHndl_t DeconfigGard::processFieldCoreOverride()
std::sort(pProcList.begin(), pProcList.end(),
compareTargetHuid);
// create list for restrictEXunits() function
procRestrict_t l_procEntry;
std::vector <procRestrict_t> l_procRestrictList;
for (TargetHandleList::const_iterator
@@ -764,22 +764,22 @@ errlHndl_t DeconfigGard::processFieldCoreOverride()
const TargetHandle_t pProc = *pProc_it;
// save info so that we can
- // restrict the number of EX units
+ // restrict the number of EC units
HWAS_DBG("pProc %.8X - pushing to proclist",
get_huid(pProc));
l_procEntry.target = pProc;
l_procEntry.group = 0;
l_procEntry.procs = pProcList.size();
- l_procEntry.maxEXs = l_fco;
+ l_procEntry.maxECs = l_fco;
l_procRestrictList.push_back(l_procEntry);
} // for pProc_it
- // restrict the EX units; units turned off are marked
+ // restrict the EC units; units turned off are marked
// present=true, functional=false, and marked with the
// appropriate deconfigure code.
- HWAS_INF("FCO: calling restrictEXunits with %d entries",
+ HWAS_INF("FCO: calling restrictECunits with %d entries",
l_procRestrictList.size());
- l_pErr = restrictEXunits(l_procRestrictList,
+ l_pErr = restrictECunits(l_procRestrictList,
true, DECONFIGURED_BY_FIELD_CORE_OVERRIDE);
if (l_pErr)
{
@@ -752,7 +752,7 @@ errlHndl_t DeconfigGard::processFieldCoreOverride()
std::sort(pProcList.begin(), pProcList.end(),
compareTargetHuid);
- // create list for restrictEXunits() function
+ // create list for restrictECunits() function
procRestrict_t l_procEntry;
std::vector <procRestrict_t> l_procRestrictList;
OpenPOWER on IntegriCloud